## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
rm(list = ls())
library(tidyverse)
library(dplyr)
library(stringr)
library(stargazer)
library(knitr)
library(pander)

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
#Load Data
FMA.Grants <- read.csv("../Processing and Analysis/Importable Data/FEMA_HMA_FMA_grants2.16.17 (Importable).csv")

PDM.Grants <- read.csv("../Processing and Analysis/Importable Data/FEMA_HMA_PDM1.11.17 (Importable).csv")

SRL.Grants <- read.csv("../Processing and Analysis/Importable Data/FEMA_HMA-SRL_grants (Importable).csv")

RFC.Grants <- read.csv("../Processing and Analysis/Importable Data/FEMA-HMA-RFC_grants (Importable).csv")

HMGP.Grants <- read.csv("../Processing and Analysis/Importable Data/FEMAHazardMitigation4.7.2017 (Importable).csv")

Disasters <- read.csv("../Processing and Analysis/Importable Data/DataVizDisasterSummariesFV12.19.2016 (Importable).csv")

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
NonDisaster.Grants <- rbind(FMA.Grants, PDM.Grants, RFC.Grants, SRL.Grants)
#Merge non-disaster grants into one dataframe#



## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
NonDisaster.Grants.Adjust1 <- NonDisaster.Grants %>%
          filter(!is.na(Project.Amount))  %>%
          separate(Date.Approved, into = c("Month.Day", "Year"), sep = -3)  #%>% #takes off month and day and creates 2 new variable 
NonDisaster.Grants.Adjust1$Century <- ifelse(NonDisaster.Grants.Adjust1$Year >= 00 & NonDisaster.Grants.Adjust1$Year <= 17 ,"20", "19")
#Create century and year variables 

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------

NonDisaster.Grants.Adjust2 <- NonDisaster.Grants.Adjust1 %>%
          unite(Year_YYYY, Century, Year, sep = "") %>%
          filter(Year_YYYY <= 2013 & Year_YYYY >= 1995) %>%
            mutate(FEMA.Amount.Paid = Project.Amount * Cost.Share.Percentage)
 #Created FEMA amount paid for grant paid based on cost of project and % shared with FEMA
#Made Year variable and filtered between 95 and 13


## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
NonDisaster.Grants.VarsFinal <- c("Region","State","Program.Area", "Year_YYYY", "FEMA.Amount.Paid")
 
NonDisaster.Grants.Final <- NonDisaster.Grants.Adjust2 %>%
         select(one_of(NonDisaster.Grants.VarsFinal))  %>%
          group_by(Year_YYYY, Program.Area, State, Region) %>%
          summarise(FEMA.Amount.Paid = sum(FEMA.Amount.Paid))

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
HMGP.Grants.Final <- HMGP.Grants %>%
          filter(!is.na(Project.Amount))  %>%
           filter(!is.na(Cost.Share.Percentage))  %>%
          filter(Status == "Approved" | Status == "Closed") %>%
          separate(Declaration.Date, into = c("Month.Day", "Year"), sep = -5) %>%
            mutate(FEMA.Amount.Paid = Project.Amount * Cost.Share.Percentage) %>%
            group_by(Year, Region, State) %>%
            summarise(FEMA.Amount.Paid = sum(FEMA.Amount.Paid)) %>%
            filter(Year <= 2013 & Year >= 1995)
  
HMGP.Grants.Final$Program.Area <- "HMGP"

names(HMGP.Grants.Final)[names(HMGP.Grants.Final) == 'Year'] <- 'Year_YYYY'

HMGP.Grants.Final$Program.Area <- as.factor(HMGP.Grants.Final$Program.Area)

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------

Grants.Final <- rbind(NonDisaster.Grants.Final, HMGP.Grants.Final)

Grants.Final$Grant.Type <- ifelse(Grants.Final$Program.Area != "HMGP", "Non-Disaster", "Disaster")

Grants.Final$SRL.Targeted.State <- ifelse(Grants.Final$State == "Connecticut" | Grants.Final$State == "Massachusetts" | Grants.Final$State == "New Jersey" | Grants.Final$State == "New York" | Grants.Final$State == "Pennsylvania" |Grants.Final$State == "Virginia" |Grants.Final$State == "Alabama" |Grants.Final$State == "Florida" |Grants.Final$State == "Kentucky" |Grants.Final$State == "Mississippi" | Grants.Final$State == "North Carolina" |Grants.Final$State == "Illinois" |Grants.Final$State == "Louisiana" |Grants.Final$State == "Oklahoma" |Grants.Final$State == "Texas" |Grants.Final$State == "Missouri" |Grants.Final$State == "California", 1, 0)

Grants.Final$Act2004.Grants <- ifelse(Grants.Final$Program.Area == "RFC" | Grants.Final$Program.Area == "SRL", 1, 0)

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
Grant_sum <- Grants.Final %>%
    group_by(Year_YYYY, Program.Area, SRL.Targeted.State, Grant.Type) %>%  
      summarise(FEMA.Amount.Paid_SUM = sum(FEMA.Amount.Paid))
#Grant_sum for Graph of SRL.Targets 

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
RLP.Claim.Amounts <- read.csv("../Processing and Analysis/Importable Data/RLP Claim Amounts 1995-2013 (Importable).csv")

SRL.Claim.Amounts.All_Properties <- read.csv("../Processing and Analysis/Importable Data/SRL Claim Amounts - 1995-2013 - All SRL Properties (Importable).csv")

RLP.Properties <- read.csv("../Processing and Analysis/Importable Data/sr15202.rlprops.feb14 (Importable).csv")

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------

#Grants.Final %>%
  #group_by(Program.Area) %>%
 # summarise(FEMA.Amount.Paid_SUM = sum(FEMA.Amount.Paid))
#Checked to be right (:

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
RLP.Claim.Amounts.Adjust1 <- RLP.Claim.Amounts %>%
                    gather(X1995, X1996, X1997, X1998, X1999, X2000, X2001, X2002, X2003, X2004, X2004, X2005, X2006, X2007, X2008, X2009, X2010, X2011, X2012, X2013, X2014, key = "XYear", value = "RLP Flood Claims Paid") %>%
                    separate(XYear, into = c("X", "Year_YYYY"), sep = 1)

#Split into year and value

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
RLP.Claim.Amounts.VarsFinal <- c("STATE", "Year_YYYY", "RLP Flood Claims Paid")
RLP.Claim.Amounts.Final <- RLP.Claim.Amounts.Adjust1 %>%
                          select(one_of(RLP.Claim.Amounts.VarsFinal)) %>%
                          filter(Year_YYYY <= 2013 & Year_YYYY >= 1995)
RLP.Claim.Amounts.Final <- subset(RLP.Claim.Amounts.Final, STATE != "TOTAL")
#select all variables and filter year and get rid of total

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
Disasters.VarsAdjust1 <- c("Year", "Region.Number", "State.Abbreviation", "State", "Disaster.Type", "Incident.Type", "Title", "County", "Region")

Disasters.Adjust1 <- Disasters %>%
  select(one_of(Disasters.VarsAdjust1)) %>%
  filter(Year <= 2013 & Year >= 1995) %>%
  filter(Disaster.Type == "DR") %>%
  filter(Incident.Type != "Drought", Incident.Type != "Fire",Incident.Type != "Mud/Landslide",Incident.Type != "Terrorist", Incident.Type != "Human Cause")

Disasters.Adjust1$Flood.Related.Disaster.Count <- ifelse(str_detect(Disasters.Adjust1$Title, "FLOOD"), 1, ifelse(str_detect(Disasters.Adjust1$Title, "HURRICANE"), 1, ifelse(str_detect(Disasters.Adjust1$Title, "TROPICAL STORM"), 1, ifelse(str_detect(Disasters.Adjust1$Title, "TYPHOON"), 1, ifelse(str_detect(Disasters.Adjust1$Title, "TSUNAMI"), 1, 0)))))

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
Disasters.Adjust1 <- subset(Disasters.Adjust1, County != "Statewide") #get rid of statewide disasters - 8 are dropped

Disasters.Final <- Disasters.Adjust1 %>%
  group_by(Region.Number, Year, State, State.Abbreviation) %>%
  summarise(Number.of.Flood.Related.Disasters = sum(Flood.Related.Disaster.Count))

names(Disasters.Final)[names(Disasters.Final) == 'Region.Number'] <- 'Region'
names(Disasters.Final)[names(Disasters.Final) == 'Year'] <- 'Year_YYYY'

###  Disasters Adjust 2 for Incident Type breakdown
Disasters.Adjust2 <- Disasters.Adjust1 %>%
  group_by(Year, Region.Number, Incident.Type, State) %>%
  summarise(sumDisasters = sum(Flood.Related.Disaster.Count))

Disasters.Adjust2$SRL.Targeted.State <- ifelse(Disasters.Adjust2$State == "Connecticut" | Disasters.Adjust2$State == "Massachusetts" | Disasters.Adjust2$State == "New Jersey" | Disasters.Adjust2$State == "New York" | Disasters.Adjust2$State == "Pennsylvania" |Disasters.Adjust2$State == "Virginia" |Disasters.Adjust2$State == "Alabama" |Disasters.Adjust2$State == "Florida" |Disasters.Adjust2$State == "Kentucky" |Disasters.Adjust2$State == "Mississippi" | Disasters.Adjust2$State == "North Carolina" |Disasters.Adjust2$State == "Illinois" |Disasters.Adjust2$State == "Louisiana" |Disasters.Adjust2$State == "Oklahoma" |Disasters.Adjust2$State == "Texas" |Disasters.Adjust2$State == "Missouri" |Disasters.Adjust2$State == "California", 1, 0)

Disasters.Final$SRL.Targeted.State <- ifelse(Disasters.Final$State == "Connecticut" | Disasters.Final$State == "Massachusetts" | Disasters.Final$State == "New Jersey" | Disasters.Final$State == "New York" | Disasters.Final$State == "Pennsylvania" |Disasters.Final$State == "Virginia" |Disasters.Final$State == "Alabama" |Disasters.Final$State == "Florida" |Disasters.Final$State == "Kentucky" |Disasters.Final$State == "Mississippi" | Disasters.Final$State == "North Carolina" |Disasters.Final$State == "Illinois" |Disasters.Final$State == "Louisiana" |Disasters.Final$State == "Oklahoma" |Disasters.Final$State == "Texas" |Disasters.Final$State == "Missouri" |Disasters.Final$State == "California", 1, 0)

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
######## IMPORTING SRL CLAIMS ############
######## ###################### ############

#library(xlsx) caused computer to crash

SRL.Resi.Insured <- read.csv("../Processing and Analysis/Importable Data/SRL.Resi.Insured.csv")
SRL.Resi.Uninsured <- read.csv("../Processing and Analysis/Importable Data/SRL.Resi.Uninsured.csv")
SRL.Nonresi.Insured <- read.csv("../Processing and Analysis/Importable Data/SRL.Nonresi.Insured.csv")
SRL.Nonresi.Uninsured <- read.csv("../Processing and Analysis/Importable Data/SRL.Nonresi.Uninsured.csv")

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
SRL.Resi.Insured.Adjust1 <- SRL.Resi.Insured %>%
                        gather(X1995, X1996, X1997, X1998, X1999, X2000, X2001, X2002, X2003, X2004, X2004, X2005, X2006, X2007, X2008, X2009, X2010, X2011, X2012, X2013, key = "XYear", value = "SRL_Flood_Claims") %>%
      separate(XYear, into = c("X", "Year_YYYY"), sep = 1)

SRL.Resi.Insured.Adjust1$Residential <- 1
SRL.Resi.Insured.Adjust1$Insured <- 1

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
SRL.Resi.Insured.VarsFinal <- c("STATE", "Year_YYYY", "SRL_Flood_Claims", "Residential", "Insured")
SRL.Resi.Insured.Final <- SRL.Resi.Insured.Adjust1 %>%
                        select(one_of(SRL.Resi.Insured.VarsFinal))
#Drop extra X variable and X2014 variable

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
SRL.Resi.Uninsured.VarsAdjust1 <- c("STATE","X1995","X1996", "X1997", "X1998", "X1999", "X2000", "X2001", "X2002", "X2003", "X2004", "X2005", "X2006", "X2007", "X2008", "X2009", "X2010", "X2011", "X2012", "X2013")
SRL.Resi.Uninsured.Adjust1 <- SRL.Resi.Uninsured %>%
  select(one_of(SRL.Resi.Uninsured.VarsAdjust1)) %>%
                        gather(X1995, X1996, X1997, X1998, X1999, X2000, X2001, X2002, X2003, X2004, X2004, X2005, X2006, X2007, X2008, X2009, X2010, X2011, X2012, X2013, key = "XYear", value = "SRL_Flood_Claims") %>%
      separate(XYear, into = c("X", "Year_YYYY"), sep = 1)

SRL.Resi.Uninsured.Adjust1$Residential <- 1
SRL.Resi.Uninsured.Adjust1$Insured <- 0

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
SRL.Resi.Uninsured.VarsFinal <- c("STATE", "Year_YYYY", "SRL_Flood_Claims", "Residential", "Insured")
SRL.Resi.Uninsured.Final <- SRL.Resi.Uninsured.Adjust1 %>%
                        select(one_of(SRL.Resi.Uninsured.VarsFinal))

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
SRL.Nonresi.Insured.VarsAdjust1 <- c("STATE","X1995","X1996", "X1997", "X1998", "X1999", "X2000", "X2001", "X2002", "X2003", "X2004", "X2005", "X2006", "X2007", "X2008", "X2009", "X2010", "X2011", "X2012", "X2013")
SRL.Nonresi.Insured.Adjust1 <- SRL.Nonresi.Insured %>%
  select(one_of(SRL.Nonresi.Insured.VarsAdjust1)) %>%
                        gather(X1995, X1996, X1997, X1998, X1999, X2000, X2001, X2002, X2003, X2004, X2004, X2005, X2006, X2007, X2008, X2009, X2010, X2011, X2012, X2013, key = "XYear", value = "SRL_Flood_Claims") %>%
      separate(XYear, into = c("X", "Year_YYYY"), sep = 1)

SRL.Nonresi.Insured.Adjust1$Residential <- 0
SRL.Nonresi.Insured.Adjust1$Insured <- 1

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
SRL.Nonresi.Insured.VarsFinal <- c("STATE", "Year_YYYY", "SRL_Flood_Claims", "Residential", "Insured")
SRL.Nonresi.Insured.Final <- SRL.Nonresi.Insured.Adjust1 %>%
                        select(one_of(SRL.Nonresi.Insured.VarsFinal))

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
SRL.Nonresi.Uninsured.Adjust1 <- SRL.Nonresi.Uninsured %>%
                        gather(X1995, X1996, X1997, X1998, X1999, X2000, X2001, X2002, X2003, X2004, X2004, X2005, X2006, X2007, X2008, X2009, X2010, X2011, X2012, X2013, key = "XYear", value = "SRL_Flood_Claims") %>%
      separate(XYear, into = c("X", "Year_YYYY"), sep = 1)

SRL.Nonresi.Uninsured.Adjust1$Residential <- 0
SRL.Nonresi.Uninsured.Adjust1$Insured <- 0

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
SRL.Nonresi.Uninsured.VarsFinal <- c("STATE", "Year_YYYY", "SRL_Flood_Claims", "Residential", "Insured")
SRL.Nonresi.Uninsured.Final <- SRL.Nonresi.Uninsured.Adjust1 %>%
                        select(one_of(SRL.Nonresi.Uninsured.VarsFinal))

SRL.Claims <- rbind(SRL.Resi.Insured.Final, SRL.Resi.Uninsured.Final, SRL.Nonresi.Insured.Final, SRL.Nonresi.Uninsured.Final)
#Merge all SRL claims indicating insured or resi or both

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
All.Claims <- merge(SRL.Claims, RLP.Claim.Amounts.Final, all.y = TRUE, all.x = TRUE, by= c("STATE", "Year_YYYY")) 

All.Claims$SRL.Targeted.State <- ifelse(All.Claims$STATE == "CONNECTICUT" | All.Claims$STATE == "MASSACHUSETTS" | All.Claims$STATE == "NEW JERSEY" | All.Claims$STATE == "NEW YORK" | All.Claims$STATE == "PENNSYLVANIA" |All.Claims$STATE == "VIRGINIA" |All.Claims$STATE == "ALABAMA" |All.Claims$STATE == "FLORIDA" |All.Claims$STATE == "KENTUCKY" |All.Claims$STATE == "MISSISSIPPI" | All.Claims$STATE == "NORTH CAROLINA" |All.Claims$STATE == "ILLINOIS" |All.Claims$STATE == "LOUISIANA" |All.Claims$STATE == "OKLAHOMA" |All.Claims$STATE == "TEXAS" |All.Claims$STATE == "MISSOURI" |All.Claims$STATE == "CALIFORNIA", 1, 0)

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
statekey <- read.csv("../Processing and Analysis/Importable Data/State Key.csv")

All.Claims$STATE <- as.character(All.Claims$STATE)
statekey$State.Abbreviation <- as.character(statekey$State.Abbreviation)
statekey <-filter(statekey, !is.na(statekey$Alt))
statekey$Alt <- as.factor(statekey$Alt)

tr.State.Abbreviation <- rep("NA",nrow(All.Claims))
for(j in 1:nrow(All.Claims)){
            for (i in 1:nrow(statekey)){
              if(All.Claims$STATE[j] == (statekey$Alt[i]))
              {tr.State.Abbreviation[j] <- statekey$State.Abbreviation[i]} 
         }         
}

All.Claims$State.Abbreviation <- tr.State.Abbreviation

Grants.Final$State <- as.character(Grants.Final$State)
statekey$State.Abbreviation <- as.character(statekey$State.Abbreviation)
statekey <-filter(statekey, !is.na(statekey$State))
statekey$Alt <- as.factor(statekey$State)

tr1.State.Abbreviation <- rep("NA",nrow(Grants.Final))
for(j in 1:nrow(Grants.Final)){
            for (i in 1:nrow(statekey)){
              if(Grants.Final$State[j] == (statekey$State[i]))
              {tr1.State.Abbreviation[j] <- statekey$State.Abbreviation[i]} 
         }         
}

Grants.Final$State.Abbreviation <- tr1.State.Abbreviation

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------

Data.Disasters.Graph <- Disasters.Final %>%
  group_by(Year_YYYY, SRL.Targeted.State) %>%
  summarise(sumDisasters = sum(Number.of.Flood.Related.Disasters))

 Data.Disasters.Graph$SRL.Targeted.State <- as.factor(Data.Disasters.Graph$SRL.Targeted.State)

#ggplot(Data.Disasters.Graph, aes(x = Year_YYYY, y = sumDisasters)) + 
 # geom_col(mapping = aes(x = Year_YYYY, y = sumDisasters, fill = SRL.Targeted.State)) + facet_wrap(~SRL.Targeted.State)
#DECEIVING GRAPH blocked for prez

## ----echo = FALSE, message=FALSE, warning = FALSE------------------------
#RLP Claims - TG vs Not TG
Data.RLPClaims.Graph <- All.Claims  %>%
  group_by(Year_YYYY, STATE, SRL.Targeted.State) %>%
  summarise(`RLP Flood Claims Paid` = mean(`RLP Flood Claims Paid`)) %>%
  group_by(Year_YYYY, SRL.Targeted.State) %>%
  summarise(sumRLP = sum(`RLP Flood Claims Paid`))

 Data.RLPClaims.Graph$SRL.Targeted.State <- as.factor(Data.RLPClaims.Graph$SRL.Targeted.State)

#ggplot(Data.RLPClaims.Graph, aes(x = Year, y = RLP.Claim.Amounts.Paid)) + 
  # geom_col(mapping = aes(x = Year_YYYY, y = sumRLP, fill = SRL.Targeted.State), #data = Data.RLPClaims.Graph) + facet_wrap(~SRL.Targeted.State) 

## ------------------------------------------------------------------------
# Let's first take a look at the RLP and SRL claim value across the timeline
Data.RLPClaims.Graph.Total <- All.Claims  %>%
  group_by(Year_YYYY, STATE, State.Abbreviation, SRL.Targeted.State) %>%
  summarise(`RLP Flood Claims Paid` = mean(`RLP Flood Claims Paid`)) %>%
  group_by(Year_YYYY) %>%
  summarise(sumRLP = sum(`RLP Flood Claims Paid`))

ggplot(Data.RLPClaims.Graph.Total, aes(x = Year_YYYY, y = sumRLP)) + 
   geom_point(mapping = aes(x = Year_YYYY, y = sumRLP), data = Data.RLPClaims.Graph.Total) +
   geom_line(mapping = aes(x = Year_YYYY, y = sumRLP, group = 1), data =Data.RLPClaims.Graph.Total)+ylim(0, 2.7e+09) + labs(x = "Year", y = "RLP Claim Amounts Paid") + theme(axis.text.x = element_text(angle = 65, hjust = 1))

Data.SRLClaims.Graph.Total <- All.Claims %>%
  filter(Residential ==1, Insured ==1) %>%
  group_by(Year_YYYY) %>%
  summarise(sumSRL.ResiInsured = sum(SRL_Flood_Claims))

ggplot(Data.SRLClaims.Graph.Total, aes(x = Year_YYYY, y = sumSRL.ResiInsured)) + 
   geom_point(mapping = aes(x = Year_YYYY, y = sumSRL.ResiInsured), data = Data.SRLClaims.Graph.Total) +
   geom_line(mapping = aes(x = Year_YYYY, y = sumSRL.ResiInsured, group = 1), data = Data.SRLClaims.Graph.Total) + labs(x = "Year", y = "SRL Resi Insured Claim Amounts Paid") + theme(axis.text.x = element_text(angle = 65, hjust = 1))
#+ylim(0, 2.7e+09) 

## ------------------------------------------------------------------------
#I will be looking at the impact of that the RFC Grant Program and the SRL Grant Program have on these Claim Amounts paid out

Data.Grants.Graph.Total <- Grants.Final %>%
  group_by(Program.Area, Year_YYYY) %>%
  summarise(sumGrants = sum(FEMA.Amount.Paid))

ggplot(Data.Grants.Graph.Total, aes(x = Year_YYYY, y = sumGrants, fill = Program.Area, group = Program.Area)) +
  geom_point(mapping = aes(x = Year_YYYY, y = sumGrants, color = Program.Area, group = Program.Area),data = filter(Data.Grants.Graph.Total, Program.Area =="SRL" | Program.Area =="RFC" | Program.Area == "PDM"| Program.Area =="LPDM"| Program.Area =="FMA"))+
         geom_line(mapping = aes( x = Year_YYYY, y = sumGrants , color = Program.Area, group = Program.Area), data = filter(Data.Grants.Graph.Total, Program.Area != "HMGP"))+ theme(axis.text.x = element_text(angle = 65, hjust = 1)) + labs( x = "Year", y = "Grant Amont Paid by FEMA")

## ------------------------------------------------------------------------
#Since the SRL Grant Program was targeted the "costliest" and most vulnerable states, majority of the fund went to this target group and my focus will be there
Data.Grants.Graph <- Grants.Final %>%
  group_by(SRL.Targeted.State, Program.Area, Year_YYYY) %>%
  summarise(sumGrants = sum(FEMA.Amount.Paid))

ggplot(Data.Grants.Graph, aes(x = Year_YYYY, y = sumGrants, fill = Program.Area, group = Program.Area)) +
  geom_point(mapping = aes(x = Year_YYYY, y = sumGrants, color = Program.Area, group = Program.Area),data = filter(Data.Grants.Graph, Program.Area =="SRL" | Program.Area =="RFC" | Program.Area == "PDM"| Program.Area =="LPDM"| Program.Area =="FMA"))+
         geom_line(mapping = aes( x = Year_YYYY, y = sumGrants , color = Program.Area, group = Program.Area), data = filter(Data.Grants.Graph, Program.Area != "HMGP")) + facet_wrap(~SRL.Targeted.State)+ theme(axis.text.x = element_text(angle = 65, hjust = 1)) + labs( x = "Year", y = "Grant Amont Paid by FEMA")

ggplot(subset(Data.Grants.Graph, SRL.Targeted.State ==1), aes(x = Year_YYYY, y = sumGrants, fill = Program.Area, group = Program.Area)) + 
 ylim(0, 8e+06) +
geom_point(mapping = aes(x = Year_YYYY, y = sumGrants/17, color = Program.Area, group = Program.Area),data = filter(Data.Grants.Graph, (Program.Area =="SRL" | Program.Area =="RFC" | Program.Area == "PDM"| Program.Area =="LPDM"| Program.Area =="FMA") & SRL.Targeted.State==1))+
         geom_line(mapping = aes( x = Year_YYYY, y = sumGrants/17 , color = Program.Area, group = Program.Area), data = filter(Data.Grants.Graph, Program.Area != "HMGP", SRL.Targeted.State == 1 ))+ theme(axis.text.x = element_text(angle = 65, hjust = 1))+ labs( x = "Year", y = "Grant Amont Paid by FEMA")

ggplot(subset(Data.Grants.Graph, SRL.Targeted.State ==0), aes(x = Year_YYYY, y = sumGrants, fill = Program.Area)) + 
  geom_point(mapping = aes(x = Year_YYYY, y = sumGrants/37, color = Program.Area, group = Program.Area),data = filter(Data.Grants.Graph, (Program.Area =="SRL" | Program.Area =="RFC" | Program.Area == "PDM"| Program.Area =="LPDM"| Program.Area =="FMA") & SRL.Targeted.State==0))+
         geom_line(mapping = aes( x = Year_YYYY, y = sumGrants/37 , color = Program.Area, group = Program.Area), data = filter(Data.Grants.Graph, Program.Area != "HMGP", SRL.Targeted.State == 0 ))+ ylim(0, 8e+06)+ theme(axis.text.x = element_text(angle = 65, hjust = 1))+ labs( x = "Year", y = "Grant Amont Paid by FEMA")


## ------------------------------------------------------------------------
#Break down the SRL Claims by this group and scale to compare
Data.SRLClaims.Graph <- All.Claims %>%
  filter(Residential ==1, Insured ==1) %>%
    group_by(Year_YYYY, SRL.Targeted.State) %>%
  summarise(sumSRL.ResiInsured = sum(SRL_Flood_Claims))

 Data.SRLClaims.Graph$SRL.Targeted.State <- as.factor(Data.SRLClaims.Graph$SRL.Targeted.State)
 
ggplot(Data.SRLClaims.Graph, aes(x = Year_YYYY, y = SRL.ResiInsured.Claim.Amount.Paid)) + 
   geom_col(mapping = aes(x = Year_YYYY, y = sumSRL.ResiInsured, fill= SRL.Targeted.State), data = Data.SRLClaims.Graph) + facet_wrap(~SRL.Targeted.State) + theme(axis.text.x = element_text(angle = 65, hjust = 1)) + labs(x = "Year", y ="SRL Resi Insured Claim Amount Paid" )

ggplot(subset(Data.SRLClaims.Graph, SRL.Targeted.State ==1), aes(x = Year_YYYY, y = Avg.SRL.Claim.Amount.for.State.in.TG)) + 
   geom_col(mapping = aes(x = Year_YYYY, y = sumSRL.ResiInsured/17)) + ylim(0, 3e+07) + theme(axis.text.x = element_text(angle = 65, hjust = 1))+ labs(x = "Year", y ="Avg SRL Claim Amount for State in TG" )

ggplot(subset(Data.SRLClaims.Graph, SRL.Targeted.State ==0), aes(x = Year_YYYY, y = sumSRL.ResiInsured)) + 
   geom_col(mapping = aes(x = Year_YYYY, y = sumSRL.ResiInsured/37))+ ylim(0, 3e+07) + theme(axis.text.x = element_text(angle = 65, hjust = 1))+ labs(x = "Year", y ="Avg SRL Claim Amount for State Not in TG" )

## ------------------------------------------------------------------------
Data.RLPClaims.Graph.Total1 <- All.Claims  %>%
  group_by(Year_YYYY, STATE, State.Abbreviation, SRL.Targeted.State) %>%
  summarise(`RLP Flood Claims Paid` = mean(`RLP Flood Claims Paid`)) %>%
  group_by(Year_YYYY, SRL.Targeted.State) %>%
  summarise(sumRLP = sum(`RLP Flood Claims Paid`))

 Data.RLPClaims.Graph.Total1$SRL.Targeted.State <- as.factor(Data.RLPClaims.Graph.Total1$SRL.Targeted.State)
 
ggplot(Data.RLPClaims.Graph.Total1, aes(x = Year_YYYY, y = sumRLP)) + 
   geom_col(mapping = aes(x = Year_YYYY, y = sumRLP, fill= SRL.Targeted.State), data = Data.RLPClaims.Graph.Total1) + facet_wrap(~SRL.Targeted.State) + theme(axis.text.x = element_text(angle = 65, hjust = 1)) + labs(x = "Year", y ="RLP Claim Amount Paid" )

ggplot(subset(Data.RLPClaims.Graph.Total1, SRL.Targeted.State ==1), aes(x = Year_YYYY, y = sumRLP)) + 
   geom_col(mapping = aes(x = Year_YYYY, y = sumRLP/17))+ ylim(0, 1.5e+08)+theme(axis.text.x = element_text(angle = 65, hjust = 1))+ labs(x = "Year", y ="Avg RLP Claim Amount for State in TG" )

ggplot(subset(Data.RLPClaims.Graph.Total1, SRL.Targeted.State ==0), aes(x = Year_YYYY, y = sumRLP)) + 
   geom_col(mapping = aes(x = Year_YYYY, y = sumRLP/37))+ ylim(0, 1.5e+08)+ theme(axis.text.x = element_text(angle = 65, hjust = 1))+ labs(x = "Year", y ="Avg RLP Claim Amount for State Not in TG" )

## ------------------------------------------------------------------------
#In order to control for disaster damages, I have data on the Hazard Mitigation Grant Program which is a Disaster Grant for "mitigation" purposes immediately following a President-declared disaster
ggplot(Data.Grants.Graph, aes(x = Year_YYYY, y = sumGrants)) +
  geom_point(mapping = aes(x = Year_YYYY, y = sumGrants, group = Program.Area),data = filter(Data.Grants.Graph, Program.Area =="HMGP"))+
         geom_line(mapping = aes( x = Year_YYYY, y = sumGrants, group = Program.Area), data = filter(Data.Grants.Graph, Program.Area == "HMGP", Year_YYYY >= 1995)) + facet_wrap(~SRL.Targeted.State)+ theme(axis.text.x = element_text(angle = 65, hjust = 1))+ labs(x = "Year", y ="HMGP Grant Total Paid" )

ggplot(subset(Data.Grants.Graph, SRL.Targeted.State ==1), aes(x = Year_YYYY, y = Avg.Disaster.Grant.Paid.to.State.in.TG, fill = Program.Area)) + 
 ylim(0, 1.7e+08) +
geom_point(mapping = aes(x = Year_YYYY, y = sumGrants/17, color = Program.Area, group = Program.Area),data = filter(Data.Grants.Graph, Program.Area =="HMGP", SRL.Targeted.State==1))+
         geom_line(mapping = aes( x = Year_YYYY, y = sumGrants/17 , color = Program.Area, group = Program.Area), data = filter(Data.Grants.Graph, Program.Area == "HMGP", SRL.Targeted.State == 1 ))+ theme(axis.text.x = element_text(angle = 65, hjust = 1))+ labs(x = "Year", y ="Avg Disaster Grant Paid to State in TG" )

ggplot(subset(Data.Grants.Graph, SRL.Targeted.State ==0), aes(x = Year_YYYY, y = sumGrants, fill = Program.Area)) + 
  ylim(0, 1.7e+08) +
geom_point(mapping = aes(x = Year_YYYY, y = sumGrants/37, color = Program.Area, group = Program.Area),data = filter(Data.Grants.Graph, Program.Area =="HMGP", SRL.Targeted.State==0))+
         geom_line(mapping = aes( x = Year_YYYY, y = sumGrants/37 , color = Program.Area, group = Program.Area), data = filter(Data.Grants.Graph, Program.Area == "HMGP", SRL.Targeted.State == 0 ))+ theme(axis.text.x = element_text(angle = 65, hjust = 1))+ labs(x = "Year", y ="Avg Disaster Grant Paid to State NOT in TG" )

## ------------------------------------------------------------------------
#Also, need to control for number of flood-related events. Data on number of county declared flood-related disasters for each state across the timeline

#Let's take a look at the target group 
ggplot(subset(Data.Disasters.Graph, SRL.Targeted.State ==1), aes(x = Year_YYYY, y = Avg.Number.Flood.Related.Disasters.in.TG.State)) + 
   geom_col(mapping = aes(x = Year_YYYY, y = sumDisasters/17)) + ylim(0,45)+labs(x = "Year", y = "Avg # County-declared Flood Related Disasters -TG State")

ggplot(subset(Data.Disasters.Graph, SRL.Targeted.State ==0), aes(x = Year_YYYY, y = sumDisasters)) + 
   geom_col(mapping = aes(x = Year_YYYY, y = sumDisasters/37)) + ylim(0,45)+labs(x = "Year", y = "Avg # County-declared Flood Related Disasters -TG State")

## ------------------------------------------------------------------------
#Closer Look at SRL Claims in Target Group

Data.SRLClaims.Graph.TG <- All.Claims %>%
  filter(Residential ==1, Insured ==1, SRL.Targeted.State == 1) %>%
    group_by(State.Abbreviation) %>%
  summarise(sumSRL.ResiInsured = sum(SRL_Flood_Claims))

ggplot(Data.SRLClaims.Graph.TG, aes(x = State.Abbreviation, y = sumSRL.ResiInsured)) + 
   geom_col(mapping = aes(x = State.Abbreviation, y = sumSRL.ResiInsured)) + theme(axis.text.x = element_text(angle = 85, hjust = 1)) + labs(x = "State", y = "SRL Resi Insured Claims Paid (1995-2013)")

Data.Grants.Graph.TG <- Grants.Final %>%
  filter(SRL.Targeted.State ==1) %>%
  filter(Program.Area != "HMGP") %>%
  group_by(Program.Area, State) %>%
  summarise(sumGrants = sum(FEMA.Amount.Paid))

ggplot(Data.Grants.Graph.TG, aes(x = State, y = sumGrants)) + 
  geom_point(mapping = aes(x = State, y = sumGrants, color = Program.Area, group = Program.Area),data = Data.Grants.Graph.TG)+
         geom_line(mapping = aes( x = State, y = sumGrants , color = Program.Area, group = Program.Area), data = Data.Grants.Graph.TG)+ theme(axis.text.x = element_text(angle = 85, hjust = 1))+ labs(x = "State", y = "Grant Total Paid by FEMA (1995-2013)")

## ------------------------------------------------------------------------
#Now let's dive into Louisiana 

Data.SRLClaims.Graph.LA <- All.Claims %>%
  filter(Residential ==1, Insured ==1, State.Abbreviation == "LA") %>%
    group_by(Year_YYYY) %>%
  summarise(sumSRL.ResiInsured = sum(SRL_Flood_Claims))

ggplot(Data.SRLClaims.Graph.LA, aes(x = Year_YYYY, y = sumSRL.ResiInsured)) + 
   geom_col(mapping = aes(x = Year_YYYY, y = sumSRL.ResiInsured)) + theme(axis.text.x = element_text(angle = 85, hjust = 1)) + labs(x = "Year", y = "SRL Resi Insured Claims Paid for LA")

Data.Grants.Graph.LA <- Grants.Final %>%
  filter(State =="Louisiana") %>%
  filter(Program.Area != "HMGP") %>%
  group_by(Program.Area, Year_YYYY) %>%
  summarise(sumGrants = sum(FEMA.Amount.Paid))

ggplot(Data.Grants.Graph.LA, aes(x = Year_YYYY, y = sumGrants)) + 
  geom_point(mapping = aes(x = Year_YYYY, y = sumGrants, color = Program.Area, group = Program.Area),data = Data.Grants.Graph.LA)+
         geom_line(mapping = aes( x = Year_YYYY, y = sumGrants , color = Program.Area, group = Program.Area), data = Data.Grants.Graph.LA)+ theme(axis.text.x = element_text(angle = 85, hjust = 1))+ labs(x = "Year", y = "Grant Total Paid by FEMA for LA")

Data.Grants.Graph.LA.HMGP <- Grants.Final %>%
  filter(State =="Louisiana") %>%
  group_by(Program.Area, Year_YYYY) %>%
  summarise(sumGrants = sum(FEMA.Amount.Paid))

ggplot(Data.Grants.Graph.LA.HMGP, aes(x = Year_YYYY, y = sumGrants)) + 
  geom_point(mapping = aes(x = Year_YYYY, y = sumGrants, color = Program.Area, group = Program.Area),data = Data.Grants.Graph.LA.HMGP)+
         geom_line(mapping = aes( x = Year_YYYY, y = sumGrants , color = Program.Area, group = Program.Area), data = Data.Grants.Graph.LA.HMGP)+ theme(axis.text.x = element_text(angle = 85, hjust = 1))+ labs(x = "Year", y = "Grant Total Paid by FEMA for LA")

## ------------------------------------------------------------------------
SRL.Claims1 <- All.Claims %>%
            filter(Residential==1, Insured==1)

SRL.Claims2 <- SRL.Claims  %>%
            filter(Residential==1, Insured==1)

SRL.Grants1 <- Grants.Final %>%
              filter(Program.Area=="SRL")
  
Plot1 <- merge(SRL.Claims1, SRL.Grants1, all.x = TRUE, by = c("Year_YYYY", "State.Abbreviation", "SRL.Targeted.State") )

Plot1[is.na(Plot1)] <- 0

Plot1sum <- Plot1 %>%
          group_by(State.Abbreviation, SRL.Targeted.State) %>%
          summarise(sumSRLgrant = sum(FEMA.Amount.Paid), sumClaims = sum(SRL_Flood_Claims))

ggplot(Plot1sum, aes( x = sumSRLgrant, y = sumClaims)) + geom_point(mapping = aes(x= sumSRLgrant, y= sumClaims)) + ggtitle("Grant vs Claims")+ facet_wrap(~SRL.Targeted.State)

Plot2sumD <- Disasters.Final %>%
              group_by(State.Abbreviation, SRL.Targeted.State) %>%
                summarise(sumDisasters = sum(Number.of.Flood.Related.Disasters))

Disasters.SRLGrantsClaims.merge <- merge(Plot1sum, Plot2sumD, all.x = TRUE, all.y = TRUE, by = c("State.Abbreviation", "SRL.Targeted.State"))

Disasters.SRLGrantsClaims.merge[is.na(Disasters.SRLGrantsClaims.merge)] <- 0

ggplot(Disasters.SRLGrantsClaims.merge, aes( x = sumDisasters, y = sumClaims)) + geom_point(mapping = aes(x= sumDisasters, y= sumClaims)) + ggtitle("Disasters vs Claims") + facet_wrap(~SRL.Targeted.State)

ggplot(Disasters.SRLGrantsClaims.merge, aes( x = sumDisasters, y = sumSRLgrant)) + geom_point(mapping = aes(x= sumDisasters, y= sumSRLgrant)) + ggtitle("Disasters vs Grant")+ facet_wrap(~SRL.Targeted.State)

## ------------------------------------------------------------------------
SRL.Claims.RegVars <- c("SRL_Flood_Claims","RLP Flood Claims Paid","State.Abbreviation", "Year_YYYY", "SRL.Targeted.State")

SRL.Claims.Reg <- SRL.Claims1 %>%
              select(one_of(SRL.Claims.RegVars)) %>%
               filter(!is.na(State.Abbreviation))
  
Reg.SRL.Data1 <- merge(SRL.Claims.Reg, Disasters.Final, all.x = TRUE, all.y = TRUE, by = c("Year_YYYY", "State.Abbreviation", "SRL.Targeted.State"))

Reg.SRL.Data.Vars <- c("Year_YYYY","State.Abbreviation", "SRL_Flood_Claims","RLP Flood Claims Paid", "Number.of.Flood.Related.Disasters", "SRL.Targeted.State")


Reg.SRL.Data1 <- Reg.SRL.Data1 %>%
            select(one_of(Reg.SRL.Data.Vars))
Reg.SRL.Data1[is.na(Reg.SRL.Data1)] <- 0


Grants.Final.Reg1 <- Grants.Final %>%
                spread(key = Program.Area, value = FEMA.Amount.Paid)%>%
               filter(!is.na(State.Abbreviation), State.Abbreviation != "NA")

Grants.Final.Reg1[is.na(Grants.Final.Reg1)] <- 0

Grants.Final.RegReady.Vars <- c("Year_YYYY","State.Abbreviation", "FMA", "HMGP", "LPDM", "PDM", "RFC", "SRL", "SRL.Targeted.State")

Grants.Final.RegReady <- Grants.Final.Reg1 %>%
  select(one_of(Grants.Final.RegReady.Vars)) %>%
  group_by(Year_YYYY, State.Abbreviation, SRL.Targeted.State) %>%
  summarise(FMA = sum(FMA), HMGP = sum(HMGP), LPDM = sum(LPDM), PDM = sum(PDM), RFC = sum(RFC), SRL = sum(SRL))

REG.DATA.SRL <- merge(Grants.Final.RegReady, Reg.SRL.Data1, all.x = TRUE, all.y = TRUE, by = c("Year_YYYY", "State.Abbreviation", "SRL.Targeted.State"))

REG.DATA.SRL.Vars <- c("Year_YYYY","State.Abbreviation", "FMA", "HMGP", "LPDM", "PDM", "RFC", "SRL", "SRL.Targeted.State", "SRL_Flood_Claims","RLP Flood Claims Paid", "Number.of.Flood.Related.Disasters")

REG.DATA.SRL <- REG.DATA.SRL %>%
  select(one_of(REG.DATA.SRL.Vars))

REG.DATA.SRL[is.na(REG.DATA.SRL)] <- 0

## ------------------------------------------------------------------------
States.Years.Matrix.df <- read.csv("../Processing and Analysis/Importable Data/State Year Matrix.csv")

States.Years.Matrix.df <-  States.Years.Matrix.df %>%
                    gather(X1995, X1996, X1997, X1998, X1999, X2000, X2001, X2002, X2003, X2004, X2004, X2005, X2006, X2007, X2008, X2009, X2010, X2011, X2012, X2013, key = "XYear", value = "NAs") %>%
                    separate(XYear, into = c("X", "Year_YYYY"), sep = 1)

State.Years.Vars <- c("State.Abbreviation","Year_YYYY", "NAs")

States.Years.Matrix.df <- States.Years.Matrix.df %>%
  select(one_of(State.Years.Vars))

REG.DATA.SRL <- merge(REG.DATA.SRL, States.Years.Matrix.df, all.y = TRUE, by = c("State.Abbreviation", "Year_YYYY"))

REG.DATA.SRL[is.na(REG.DATA.SRL)] <- 0



## ------------------------------------------------------------------------
PropertyDamageData <- read.csv("../Processing and Analysis/Importable Data/PropertyDamageData.csv")

PropertyDamageData1 <- PropertyDamageData %>%
                    gather(X1996, X1997, X1998, X1999, X2000, X2001, X2002, X2003, X2004, X2004, X2005, X2006, X2007, X2008, X2009, X2010, X2011, X2012, X2013, key = "XYear", value = "Property_Damage_mmUSD") %>%
                    separate(XYear, into = c("X", "Year_YYYY"), sep = 1)

PropertyDamageDataVars <- c("State.Abbreviation", "Year_YYYY", "Property_Damage_mmUSD")
PropertyDamageData.Final <- PropertyDamageData1 %>%
  select(one_of(PropertyDamageDataVars))
  

## ------------------------------------------------------------------------
REG.DATA.SRL <- merge(REG.DATA.SRL, PropertyDamageData.Final, all.y = TRUE, by = c("State.Abbreviation", "Year_YYYY"))
REG.DATA.SRL$Property_Damage_mmUSD <- as.numeric(REG.DATA.SRL$Property_Damage_mmUSD)

## ------------------------------------------------------------------------
lsdv.lin.model1 <- SRL_Flood_Claims ~ FMA + HMGP + LPDM + PDM + RFC + SRL  + Number.of.Flood.Related.Disasters + as.factor(Year_YYYY) + as.factor(State.Abbreviation)
lsdv.lin..est <- lm(lsdv.lin.model1,           
              data = REG.DATA.SRL) 
summary(lsdv.lin..est)

## ------------------------------------------------------------------------
REG.DATA.SRL$lSRL_Flood_Claims <- log(REG.DATA.SRL$SRL_Flood_Claims+ sqrt((REG.DATA.SRL$SRL_Flood_Claims^2)+1))
REG.DATA.SRL$lRLP_Flood_Claims_Paid <- log(REG.DATA.SRL$`RLP Flood Claims Paid`+ sqrt((REG.DATA.SRL$`RLP Flood Claims Paid`^2)+1))
REG.DATA.SRL$lFMA <- log(REG.DATA.SRL$FMA+ sqrt((REG.DATA.SRL$FMA^2)+1))
REG.DATA.SRL$lPDM <- log(REG.DATA.SRL$PDM+ sqrt((REG.DATA.SRL$PDM^2)+1))
REG.DATA.SRL$lLPDM <- log(REG.DATA.SRL$LPDM+ sqrt((REG.DATA.SRL$LPDM^2)+1))
REG.DATA.SRL$lRFC <- log(REG.DATA.SRL$RFC+ sqrt((REG.DATA.SRL$RFC^2)+1))
REG.DATA.SRL$lSRL <- log(REG.DATA.SRL$SRL+ sqrt((REG.DATA.SRL$SRL^2)+1))
REG.DATA.SRL$lHMGP <- log(REG.DATA.SRL$HMGP+ sqrt((REG.DATA.SRL$HMGP^2)+1))
REG.DATA.SRL$ldamages <- log(REG.DATA.SRL$Property_Damage_mmUSD+ sqrt((REG.DATA.SRL$Property_Damage_mmUSD^2)+1))

lsdv.ln.model1 <- lSRL_Flood_Claims ~ lFMA + lHMGP + lLPDM + lPDM + lRFC + lSRL + ldamages+ Number.of.Flood.Related.Disasters +  as.factor(Year_YYYY) + as.factor(State.Abbreviation)

lsdv.ln.est <- lm(lsdv.ln.model1,           
              data = REG.DATA.SRL) 
#summary(lsdv.ln.est)

## ------------------------------------------------------------------------
Graphs.log.REG.DATA.SRL <- REG.DATA.SRL %>%
                        group_by(State.Abbreviation, SRL.Targeted.State) %>%
                        summarise(SRL = sum(SRL), Number.of.Flood.Related.Disasters = sum(Number.of.Flood.Related.Disasters), HMGP = sum(HMGP), SRL_Flood_Claims = sum(SRL_Flood_Claims))

ggplot(Graphs.log.REG.DATA.SRL, aes( x = SRL, y = SRL_Flood_Claims)) + geom_point(mapping = aes(x= SRL, y= SRL_Flood_Claims)) + ggtitle("SRL vs Claims") + facet_wrap(~SRL.Targeted.State)

ggplot(Graphs.log.REG.DATA.SRL, aes( x = Number.of.Flood.Related.Disasters, y = SRL_Flood_Claims)) + geom_point(mapping = aes(x= Number.of.Flood.Related.Disasters, y= SRL_Flood_Claims)) + ggtitle("Disasters vs Claims") + facet_wrap(~SRL.Targeted.State)

ggplot(Graphs.log.REG.DATA.SRL, aes( x = HMGP, y = SRL_Flood_Claims)) + geom_point(mapping = aes(x= HMGP, y= SRL_Flood_Claims)) + ggtitle("Disaster Grant vs Claims")+ facet_wrap(~SRL.Targeted.State)

## ------------------------------------------------------------------------
Graphs.log.REG.DATA.SRL2 <- REG.DATA.SRL %>%
                        group_by(Year_YYYY, SRL.Targeted.State) %>%
                        summarise(SRL = sum(SRL), Number.of.Flood.Related.Disasters = sum(Number.of.Flood.Related.Disasters), HMGP = sum(HMGP), SRL_Flood_Claims = sum(SRL_Flood_Claims))

ggplot(Graphs.log.REG.DATA.SRL2, aes( x = SRL, y = SRL_Flood_Claims)) + geom_point(mapping = aes(x= SRL, y= SRL_Flood_Claims)) + ggtitle("SRL vs Claims") + facet_wrap(~SRL.Targeted.State)

ggplot(Graphs.log.REG.DATA.SRL2, aes( x = Number.of.Flood.Related.Disasters, y = SRL_Flood_Claims)) + geom_point(mapping = aes(x= Number.of.Flood.Related.Disasters, y= SRL_Flood_Claims)) + ggtitle("Disasters vs Claims") + facet_wrap(~SRL.Targeted.State)

ggplot(Graphs.log.REG.DATA.SRL2, aes( x = HMGP, y = SRL_Flood_Claims)) + geom_point(mapping = aes(x= HMGP, y= SRL_Flood_Claims)) + ggtitle("Disaster Grant vs Claims")+ facet_wrap(~SRL.Targeted.State)

## ------------------------------------------------------------------------

Graphs.log.REG.DATA.SRL$lSRL_Flood_Claims <- log(Graphs.log.REG.DATA.SRL$SRL_Flood_Claims + sqrt((Graphs.log.REG.DATA.SRL$SRL_Flood_Claims^2) + 1))

Graphs.log.REG.DATA.SRL$lSRL <- log(Graphs.log.REG.DATA.SRL$SRL + sqrt((Graphs.log.REG.DATA.SRL$SRL^2) + 1))

Graphs.log.REG.DATA.SRL$lHMGP <- log(Graphs.log.REG.DATA.SRL$HMGP + sqrt((Graphs.log.REG.DATA.SRL$HMGP^2) + 1))

ggplot(Graphs.log.REG.DATA.SRL, aes( x = lSRL, y = lSRL_Flood_Claims)) + geom_point(mapping = aes(x= lSRL, y= lSRL_Flood_Claims)) + ggtitle("log SRL vs log Claims") + facet_wrap(~SRL.Targeted.State)

ggplot(Graphs.log.REG.DATA.SRL, aes( x = Number.of.Flood.Related.Disasters, y = lSRL_Flood_Claims)) + geom_point(mapping = aes(x= Number.of.Flood.Related.Disasters, y= lSRL_Flood_Claims)) + ggtitle("Disasters vs log Claims") + facet_wrap(~SRL.Targeted.State)

ggplot(Graphs.log.REG.DATA.SRL, aes( x = lHMGP, y = lSRL_Flood_Claims)) + geom_point(mapping = aes(x= lHMGP, y= lSRL_Flood_Claims)) + ggtitle("log Disaster Grant vs log Claims")+ facet_wrap(~SRL.Targeted.State)

hist(Graphs.log.REG.DATA.SRL$lSRL_Flood_Claims)
ggplot(Graphs.log.REG.DATA.SRL, aes(x = lSRL_Flood_Claims)) +geom_histogram(mapping = aes(x = lSRL_Flood_Claims), data = Graphs.log.REG.DATA.SRL) 

## ------------------------------------------------------------------------
Graphs.log.REG.DATA.SRL2$lSRL_Flood_Claims <- log(Graphs.log.REG.DATA.SRL2$SRL_Flood_Claims + sqrt((Graphs.log.REG.DATA.SRL2$SRL_Flood_Claims^2) + 1))

Graphs.log.REG.DATA.SRL2$lSRL <- log(Graphs.log.REG.DATA.SRL2$SRL + sqrt((Graphs.log.REG.DATA.SRL2$SRL^2) + 1))

Graphs.log.REG.DATA.SRL2$lHMGP <- log(Graphs.log.REG.DATA.SRL2$HMGP + sqrt((Graphs.log.REG.DATA.SRL2$HMGP^2) + 1))

ggplot(Graphs.log.REG.DATA.SRL2, aes( x = lSRL, y = lSRL_Flood_Claims)) + geom_point(mapping = aes(x= lSRL, y= lSRL_Flood_Claims)) + ggtitle("log SRL vs log Claims") + facet_wrap(~SRL.Targeted.State)

ggplot(Graphs.log.REG.DATA.SRL2, aes( x = Number.of.Flood.Related.Disasters, y = lSRL_Flood_Claims)) + geom_point(mapping = aes(x= Number.of.Flood.Related.Disasters, y= lSRL_Flood_Claims)) + ggtitle("Disasters vs log Claims") + facet_wrap(~SRL.Targeted.State)

ggplot(Graphs.log.REG.DATA.SRL2, aes( x = lHMGP, y = lSRL_Flood_Claims)) + geom_point(mapping = aes(x= lHMGP, y= lSRL_Flood_Claims)) + ggtitle("log Disaster Grant vs log Claims")+ facet_wrap(~SRL.Targeted.State)

hist(Graphs.log.REG.DATA.SRL2$lSRL_Flood_Claims)
ggplot(Graphs.log.REG.DATA.SRL2, aes(x = lSRL_Flood_Claims)) +geom_histogram(mapping = aes(x = lSRL_Flood_Claims), data = Graphs.log.REG.DATA.SRL2)

## ------------------------------------------------------------------------
REG.DATA.SRL.TGonly <- REG.DATA.SRL %>%
  filter(SRL.Targeted.State == 1)

lsdv.ln.model2 <- lSRL_Flood_Claims ~ lFMA + lHMGP + lLPDM + lPDM + lRFC + lSRL  + ldamages + Number.of.Flood.Related.Disasters  + as.factor(State.Abbreviation)+  as.factor(Year_YYYY)

lsdv.ln.est2 <- lm(lsdv.ln.model2,           
              data = REG.DATA.SRL.TGonly) 
#summary(lsdv.ln.est2)


## ------------------------------------------------------------------------
library(plm)

fe.ln.model1 <- lSRL_Flood_Claims ~ lFMA + lHMGP + lLPDM + lPDM + lRFC + lSRL + ldamages + Number.of.Flood.Related.Disasters 

fe.est <- plm(fe.ln.model1,                 ##  tell it the model you want to run 
              data = REG.DATA.SRL,          ##  tell it the dataset to use
              index = c("State.Abbreviation", "Year_YYYY"), ##  tell it the variables that indicate the cross section units and time
              model = "within",            ##  The type of model to run (there are different types of panel models)
              effect = "twoways")     

#summary(fe.est)
phtest(fe.ln.model1, data = REG.DATA.SRL)

## ------------------------------------------------------------------------
##TG only - no lag## with plm (same results as above)

fe.estTG <- plm(fe.ln.model1,                 ##  tell it the model you want to run 
              data = REG.DATA.SRL.TGonly,          ##  tell it the dataset to use
              index = c("State.Abbreviation", "Year_YYYY"), ##  tell it the variables that indicate the cross section units and time
              model = "within",            ##  The type of model to run (there are different types of panel models)
              effect = "twoways")     
#summary(fe.estTG)

## ------------------------------------------------------------------------
p.data.REG <- pdata.frame(REG.DATA.SRL, index = "State.Abbreviation")
names(p.data.REG)[names(p.data.REG) == 'lRLP_Flood_Claims_Paid'] <- 'lRLP_Flood_Claims'
names(p.data.REG)[names(p.data.REG) == 'Number.of.Flood.Related.Disasters'] <- 'FloodDisastersCount'

p.data.REG$laglSRL1 <- lag(p.data.REG$lSRL,1)
p.data.REG$laglRFC1 <- lag(p.data.REG$lRFC,1)
p.data.REG$laglPDM1 <- lag(p.data.REG$lPDM,1)
p.data.REG$laglLPDM1 <- lag(p.data.REG$lLPDM,1)
p.data.REG$laglFMA1 <- lag(p.data.REG$lFMA,1)
p.data.REG$laglHMGP1 <- lag(p.data.REG$lHMGP,1)

p.data.REG$laglSRL2 <- lag(p.data.REG$lSRL,2)
p.data.REG$laglRFC2 <- lag(p.data.REG$lRFC,2)
p.data.REG$laglPDM2 <- lag(p.data.REG$lPDM,2)
p.data.REG$laglLPDM2 <- lag(p.data.REG$lLPDM,2)
p.data.REG$laglFMA2 <- lag(p.data.REG$lFMA,2)
p.data.REG$laglHMGP2 <- lag(p.data.REG$lHMGP,2)

p.data.REG$laglSRL3 <- lag(p.data.REG$lSRL,3)
p.data.REG$laglRFC3 <- lag(p.data.REG$lRFC,3)
p.data.REG$laglPDM3 <- lag(p.data.REG$lPDM,3)
p.data.REG$laglLPDM3 <- lag(p.data.REG$lLPDM,3)
p.data.REG$laglFMA3 <- lag(p.data.REG$lFMA,3)
p.data.REG$laglHMGP3 <- lag(p.data.REG$lHMGP,3)

RLPfe.ln.modellag1 <- lRLP_Flood_Claims ~ laglFMA1 + lFMA  + laglHMGP1+ laglLPDM1 + lLPDM + laglPDM1 + lPDM + laglRFC1 + lRFC+ laglSRL1 + lSRL + FloodDisastersCount + ldamages

RLPfe.ln.modellag2 <- lRLP_Flood_Claims ~ lFMA + laglFMA1 + laglFMA2  + laglHMGP1 +laglHMGP2+ lLPDM + laglLPDM1 + laglLPDM2 + lPDM + laglPDM1 + laglPDM2 + lRFC + laglRFC1 + laglRFC2 +lSRL +  laglSRL1 + laglSRL2 + FloodDisastersCount +ldamages

RLPfe.ln.modellag3 <- lRLP_Flood_Claims ~ lFMA + laglFMA1 + laglFMA2 + laglFMA3 + laglHMGP1+ laglHMGP2 +laglHMGP3+ lLPDM + laglLPDM1 + laglLPDM2 + laglLPDM3 + lPDM+ laglPDM1 + laglPDM2  + laglPDM3 + lRFC+ laglRFC1 + laglRFC2  +laglRFC3+ lSRL+  laglSRL1 + laglSRL2 +laglSRL3+ FloodDisastersCount +ldamages


SRLfe.ln.modellag1 <- lSRL_Flood_Claims ~ laglFMA1 + lFMA  + laglHMGP1+ laglLPDM1 + lLPDM + laglPDM1 + lPDM + laglRFC1 + lRFC+ laglSRL1 + lSRL + FloodDisastersCount + ldamages

SRLfe.ln.modellag2 <- lSRL_Flood_Claims ~ lFMA + laglFMA1 + laglFMA2  + laglHMGP1 +laglHMGP2+ lLPDM + laglLPDM1 + laglLPDM2 + lPDM + laglPDM1 + laglPDM2 + lRFC + laglRFC1 + laglRFC2 +lSRL +  laglSRL1 + laglSRL2 + FloodDisastersCount +ldamages

SRLfe.ln.modellag3 <- lSRL_Flood_Claims ~ lFMA + laglFMA1 + laglFMA2 + laglFMA3  + laglHMGP1+ laglHMGP2 +laglHMGP3+ lLPDM + laglLPDM1 + laglLPDM2 + laglLPDM3 + lPDM+ laglPDM1 + laglPDM2  + laglPDM3 + lRFC+ laglRFC1 + laglRFC2  +laglRFC3+ lSRL+  laglSRL1 + laglSRL2 +laglSRL3+ FloodDisastersCount +ldamages




## ------------------------------------------------------------------------
SRLfe.estlag1 <- plm(SRLfe.ln.modellag1,                
              data = p.data.REG,          
              index = c("State.Abbreviation", "Year_YYYY"), 
              model = "within",       
              effect = "twoways") 
SRLfe.estlag2 <- plm(SRLfe.ln.modellag2,                
              data = p.data.REG,          
              index = c("State.Abbreviation", "Year_YYYY"), 
              model = "within",       
              effect = "twoways")    
SRLfe.estlag3 <- plm(SRLfe.ln.modellag3,                
              data = p.data.REG,          
              index = c("State.Abbreviation", "Year_YYYY"), 
              model = "within",       
              effect = "twoways")    


RLPfe.estlag1 <- plm(RLPfe.ln.modellag1,                
              data = p.data.REG,          
              index = c("State.Abbreviation", "Year_YYYY"), 
              model = "within",       
              effect = "twoways") 
RLPfe.estlag2 <- plm(RLPfe.ln.modellag2,                
              data = p.data.REG,          
              index = c("State.Abbreviation", "Year_YYYY"), 
              model = "within",       
              effect = "twoways") 
RLPfe.estlag3 <- plm(RLPfe.ln.modellag3,                
              data = p.data.REG,          
              index = c("State.Abbreviation", "Year_YYYY"), 
              model = "within",       
              effect = "twoways") 



## ------------------------------------------------------------------------
###TG ONLY#####
p.data.REG.TGonly <- pdata.frame(REG.DATA.SRL.TGonly, index = "State.Abbreviation")

p.data.REG.TGonly$laglSRL1 <- lag(p.data.REG.TGonly$lSRL,1)
p.data.REG.TGonly$laglRFC1<- lag(p.data.REG.TGonly$lRFC,1)
p.data.REG.TGonly$laglPDM1 <- lag(p.data.REG.TGonly$lPDM,1)
p.data.REG.TGonly$laglLPDM1 <- lag(p.data.REG.TGonly$lLPDM,1)
p.data.REG.TGonly$laglFMA1 <- lag(p.data.REG.TGonly$lFMA,1)
p.data.REG.TGonly$laglHMGP1 <- lag(p.data.REG.TGonly$lHMGP,1)

p.data.REG.TGonly$laglSRL2 <- lag(p.data.REG.TGonly$lSRL,2)
p.data.REG.TGonly$laglRFC2 <- lag(p.data.REG.TGonly$lRFC,2)
p.data.REG.TGonly$laglPDM2 <- lag(p.data.REG.TGonly$lPDM,2)
p.data.REG.TGonly$laglLPDM2 <- lag(p.data.REG.TGonly$lLPDM,2)
p.data.REG.TGonly$laglFMA2 <- lag(p.data.REG.TGonly$lFMA,2)
p.data.REG.TGonly$laglHMGP2 <- lag(p.data.REG.TGonly$lHMGP,2)

p.data.REG.TGonly$laglSRL3 <- lag(p.data.REG.TGonly$lSRL,3)
p.data.REG.TGonly$laglRFC3 <- lag(p.data.REG.TGonly$lRFC,3)
p.data.REG.TGonly$laglPDM3 <- lag(p.data.REG.TGonly$lPDM,3)
p.data.REG.TGonly$laglLPDM3 <- lag(p.data.REG.TGonly$lLPDM,3)
p.data.REG.TGonly$laglFMA3 <- lag(p.data.REG.TGonly$lFMA,3)
p.data.REG.TGonly$laglHMGP3 <- lag(p.data.REG.TGonly$lHMGP,3)
names(p.data.REG.TGonly)[names(p.data.REG.TGonly) == 'lRLP_Flood_Claims_Paid'] <- 'lRLP_Flood_Claims'
names(p.data.REG.TGonly)[names(p.data.REG.TGonly) == 'Number.of.Flood.Related.Disasters'] <- 'FloodDisastersCount'
SRLfe.estlag1TG <- plm(SRLfe.ln.modellag1,              
              data = p.data.REG.TGonly,       
              index = c("State.Abbreviation", "Year_YYYY"), 
              model = "within", 
              effect = "twoways")     
SRLfe.estlag2TG <- plm(SRLfe.ln.modellag2,              
              data = p.data.REG.TGonly,       
              index = c("State.Abbreviation", "Year_YYYY"), 
              model = "within", 
              effect = "twoways") 
SRLfe.estlag3TG <- plm(SRLfe.ln.modellag3,              
              data = p.data.REG.TGonly,       
              index = c("State.Abbreviation", "Year_YYYY"), 
              model = "within", 
              effect = "twoways")    


RLPfe.estlag1TG <- plm(RLPfe.ln.modellag1,              
              data = p.data.REG.TGonly,       
              index = c("State.Abbreviation", "Year_YYYY"), 
              model = "within", 
              effect = "twoways")     
RLPfe.estlag2TG <- plm(RLPfe.ln.modellag2,              
              data = p.data.REG.TGonly,       
              index = c("State.Abbreviation", "Year_YYYY"), 
              model = "within", 
              effect = "twoways")  
RLPfe.estlag3TG <- plm(RLPfe.ln.modellag3,              
              data = p.data.REG.TGonly,       
              index = c("State.Abbreviation", "Year_YYYY"), 
              model = "within", 
              effect = "twoways")  



## ------------------------------------------------------------------------

stargazer(SRLfe.estlag1, SRLfe.estlag2, SRLfe.estlag3,
          type="text",                   ## type of out
          title = "SRL/RLP All States Lagged Panel Fixed Effects Regressions",
          keep.stat=c("n"))                ##  other info to include in table

stargazer(SRLfe.estlag1TG, SRLfe.estlag2TG, SRLfe.estlag3TG,
          type="text",                   ## type of out
          title = "SRL Targeted States Lagged Panel Fixed Effects Regressions",
          keep.stat=c("n"))  

stargazer(RLPfe.estlag1, RLPfe.estlag2, RLPfe.estlag3,
          type="text",                   ## type of out
          title = "RLP All States Lagged Panel Fixed Effects Regressions",
          keep.stat=c("n"))                ##  other info to include in table

stargazer(RLPfe.estlag1TG,RLPfe.estlag2TG,RLPfe.estlag3TG, 
          type="text",                   ## type of out
          title = "RLP Targeted States Lagged Panel Fixed Effects Regressions",
          keep.stat=c("n"))  

## ------------------------------------------------------------------------


## ------------------------------------------------------------------------


Data.Grants.Graph$SRL.Targeted.State[Data.Grants.Graph$SRL.Targeted.State=="1"] <- "SRL Targeted Group" 
Data.Grants.Graph$SRL.Targeted.State[Data.Grants.Graph$SRL.Targeted.State=="0"] <- "Not Targeted"   
  
Data.Grants.Graph$sumGrantsM <- Data.Grants.Graph$sumGrants/1000000

ggplot(Data.Grants.Graph, aes(x = Year_YYYY, y = sumGrantsM, fill = Program.Area, group = Program.Area)) +
  geom_point(mapping = aes(x = Year_YYYY, y = sumGrantsM, color = Program.Area, group = Program.Area),data = filter(Data.Grants.Graph, Program.Area =="SRL" | Program.Area =="RFC" | Program.Area == "PDM"| Program.Area =="LPDM"| Program.Area =="FMA"))+
         geom_line(mapping = aes( x = Year_YYYY, y = sumGrantsM, color = Program.Area, group = Program.Area), data = filter(Data.Grants.Graph, Program.Area != "HMGP")) + facet_wrap(~SRL.Targeted.State)+ theme(axis.text.x = element_text(angle = 65, hjust = 1)) + labs( x = "Year", y = "Grant Amont Paid by FEMA ($MM) ")


## ------------------------------------------------------------------------

Data.RLPClaims.Graph.Total <- All.Claims  %>%
  group_by(Year_YYYY, STATE, State.Abbreviation, SRL.Targeted.State) %>%
  summarise(`RLP Flood Claims Paid` = mean(`RLP Flood Claims Paid`)) %>%
  group_by(Year_YYYY, SRL.Targeted.State) %>%
  summarise(sumRLP = sum(`RLP Flood Claims Paid`))

Data.RLPClaims.Graph.Total$sumRLPb <- Data.RLPClaims.Graph.Total$sumRLP/10^6

Data.RLPClaims.Graph.Total$SRL.Targeted.State[Data.RLPClaims.Graph.Total$SRL.Targeted.State=="1"] <- "SRL Targeted Group" 
Data.RLPClaims.Graph.Total$SRL.Targeted.State[Data.RLPClaims.Graph.Total$SRL.Targeted.State=="0"] <- "Not Targeted"   

ggplot(Data.RLPClaims.Graph.Total, aes(x = Year_YYYY, y = sumRLPb)) + 
   geom_point(mapping = aes(x = Year_YYYY, y = sumRLPb), data = Data.RLPClaims.Graph.Total) +
   geom_line(mapping = aes(x = Year_YYYY, y = sumRLPb, group = 1), data =Data.RLPClaims.Graph.Total)+ labs(x = "Year", y = "RL Claim Amounts Paid (Millions $) ") + theme(axis.text.x = element_text(angle = 65, hjust = 1))+facet_wrap( ~SRL.Targeted.State)

Data.SRLClaims.Graph.Total <- All.Claims %>%
  filter(Residential ==1, Insured ==1) %>%
  group_by(Year_YYYY, SRL.Targeted.State) %>%
  summarise(sumSRL.ResiInsured = sum(SRL_Flood_Claims))

Data.SRLClaims.Graph.Total$sumSRL.ResiInsuredm <- Data.SRLClaims.Graph.Total$sumSRL.ResiInsured/10^6

Data.SRLClaims.Graph.Total$SRL.Targeted.State[Data.SRLClaims.Graph.Total$SRL.Targeted.State=="1"] <- "SRL Targeted Group" 
Data.SRLClaims.Graph.Total$SRL.Targeted.State[Data.SRLClaims.Graph.Total$SRL.Targeted.State=="0"] <- "Not Targeted"   

ggplot(Data.SRLClaims.Graph.Total, aes(x = Year_YYYY, y = sumSRL.ResiInsuredm)) + 
   geom_point(mapping = aes(x = Year_YYYY, y = sumSRL.ResiInsuredm), data = Data.SRLClaims.Graph.Total) +
   geom_line(mapping = aes(x = Year_YYYY, y = sumSRL.ResiInsuredm, group = 1), data = Data.SRLClaims.Graph.Total) + labs(x = "Year", y = "SRL Claim Amounts Paid (Millions $) ") + theme(axis.text.x = element_text(angle = 65, hjust = 1)) +facet_wrap( ~SRL.Targeted.State)


## ------------------------------------------------------------------------
p.data.REG$FMAm <- p.data.REG$FMA/10^6
p.data.REG$HMGPm <- p.data.REG$HMGP/10^6
p.data.REG$LPDMm <-p.data.REG$LPDM/10^6
p.data.REG$PDMm <-p.data.REG$PDM/10^6
p.data.REG$RFCm <-p.data.REG$RFC/10^6
p.data.REG$SRLm <-p.data.REG$SRL/10^6
p.data.REG$SRL_Flood_Claimsm <-p.data.REG$SRL_Flood_Claims/10^6
p.data.REG$`RLP Flood Claims Paidm` <- p.data.REG$`RLP Flood Claims Paid`/10^6

#stargazer(subset(p.data.REG, SRL.Targeted.State ==1)[c("FMAm", "HMGPm", "LPDMm", "PDMm", "RFCm", "SRLm", "SRL_Flood_Claimsm", "RLP_Flood_Claimsm", "FloodDisastersCount", "Property_Damage_mmUSD")], 
     #     type = "text", 
     #     covariate.labels = c("FMA", "HMGP", "LPDM", "PDM", "RFC", "SRL", "SRL Flood Claims Paid", "RL Flood Claims Paid", "County-Declared Flood Disasters", "Property Damages from Disasters"), 
    #      title = "Descriptive Statistics for Targeted States (1996-2013)",
    #      digits=1, nobs = FALSE, mean.std = TRUE, median = TRUE, iqr = TRUE)

##stargazer(subset(p.data.REG, SRL.Targeted.State ==0)[c("FMAm", "HMGPm", "LPDMm", "PDMm", "RFCm", "SRLm", "SRL_Flood_Claimsm", "RLP_Flood_Claimsm", "FloodDisastersCount", "Property_Damage_mmUSD")], 
    #      type = "text", 
    #      covariate.labels = c("FMA", "HMGP", "LPDM", "PDM", "RFC", "SRL", "SRL Flood Claims Paid", "RL Flood Claims Paid", "County-Declared Flood Disasters", "Property Damages from Disasters"), 
    #       title = "Descriptive Statistics for Not Targeted States (1996-2013)",
    #      digits=1, nobs = FALSE, mean.std = TRUE, median = TRUE, iqr = TRUE)

## ------------------------------------------------------------------------
#stargazer(RLPfe.estlag3, SRLfe.estlag3,
 #         type="text",                   ## type of out
  #        title = "Lagged Panel Fixed Effects Log-log Regressions - US",
   #         keep=c("\\blaglFMA3\\b", "\\blaglLPDM2\\b", "\\blaglPDM\\b","\\blaglRFC\\b","\\bNumber.of.Flood.Related.Disasters\\b","\\bldamages\\b"),
   #      omit.table.layout = "sn",
    #     single.row = TRUE,
     #   covariate.labels = c("laglFMA3", "laglLPDM2", "laglPDM","laglRFC","FloodDisasterCount","ldamages")) 

#stargazer(RLPfe.estlag3TG,SRLfe.estlag3TG,
 #         type="text",                   ## type of out
  #        title = "Lagged Panel Fixed Effects Log-log Regressions - TG",
   #        dep.var.labels.include = TRUE,
    #     keep=c("\\blaglFMA3\\b", "\\blaglHMGP2\\b", "\\blLPDM\\b","\\blaglSRL\\b","\\blaglSRL3\\b","\\blaglRFC\\b","\\bNumber.of.Flood.Related.Disasters\\b","\\bldamages\\b"),
     #    omit.table.layout = "sn",
      #   single.row = TRUE,
       # covariate.labels = c("laglFMA3", "laglHMGP2", "lLPDM","laglRFC","laglSRL","laglSRL3","FloodDisasterCount","ldamages"))



## ------------------------------------------------------------------------
write.csv(p.data.REG, "finaldataset.csv")
write.csv(Data.RLPClaims.Graph.Total, "Data.RLPClaims.Graph.Total.csv")
write.csv(Data.SRLClaims.Graph.Total, "Data.SRLClaims.Graph.Total.csv")
write.csv(Data.Grants.Graph, "Data.Grants.Graph.csv")
write.csv(All.Claims, "All.Claims.csv")
write.csv(Grants.Final, "Grants.Final.csv")
